@@ -36,7 +36,7 @@ class Compress:
             self.figure_data = ET.parse(svg_file) # Parse svg data as xml
         except ET.XMLSyntaxError, e:
             '''
-            Large svgs may trigger lxml's 'excessive depth in document' error
+            Large svgs may trigger lxml's 'excessive depth in document' exception
             '''
             warnings.warn('lxml error: %s - Trying huge xml parser' %(e.message))
             huge_parser = ET.XMLParser(huge_tree = True)
@@ -314,34 +314,21 @@ class Compress:
         prefix_endindex = self.root.tag.rindex('}')
         return self.root.tag[:(prefix_endindex + 1)]
     
-    def optimize(self, inputfile, outputfile = None):
+    def optimize(self, inputfile, outputfile = None, optimize_options = {}):
         '''
         Use package 'Scour' to optimize the compressed svg (e.g. remove
         unused nodes).
         '''
         if outputfile == None:
             outputfile = '%s_opt.svg' %(self.filename)
-#            Defaults:
-#                 {'strip_ids': False, 'shorten_ids': False, 'simple_colors': True, 
-#                  'strip_comments': False, 'remove_metadata': False, 'outfilename': None, 
-#                  'group_create': False, 'protect_ids_noninkscape': False, 'indent_type': 'space', 
-#                  'keep_editor_data': False, 'shorten_ids_prefix': '', 'renderer_workaround': True, 
-#                  'style_to_xml': True, 'protect_ids_prefix': None, 'enable_viewboxing': False, 
-#                  'digits': 5, 'embed_rasters': True, 'infilename': None, 'strip_xml_prolog': False, 
-#                  'group_collapse': True, 'quiet': False, 'protect_ids_list': None}
-#         wrap_scour.optimize(inputfile, outputfile, strip_ids = True, shorten_ids = True, 
-#                             simple_colors = True, strip_comments = True, remove_metadata = True, 
-#                             group_create = True, protect_ids_noninkscape = False,
-#                             indent_type = None, keep_editor_data = False, renderer_workaround = False, 
-#                             style_to_xml = True, digits = 5, embed_rasters = True, strip_xml_prolog = True, 
-#                             group_collapse = True)
-        vector_utils.optimize_svg(inputfile, outputfile)
+        vector_utils.optimize_svg(inputfile, outputfile, **optimize_options)
         final_kb = vector_utils.get_kb(outputfile) # Get the compressed size in KBytes
         self._append_report('Compressed %sKB to %sKB' %(self.initial_kb, final_kb))
         self._append_report('Saved to %s' %(outputfile))
 
 def compress_by_method(filename, compression_type, curve_fidelity = 10, outputfile = None,
-                       pre_select = False, selection_tuple = ('', ''), optimize = True, **kwargs):
+                       pre_select = False, selection_tuple = ('', ''), optimize = True,
+                       optimize_options = {}, **kwargs):
     '''
     Convenience function for 1-step compression of svg files.
     Inputs:
@@ -363,6 +350,9 @@ def compress_by_method(filename, compression_type, curve_fidelity = 10, outputfi
           size. Optional, defaults to ('', '')
         optimize(bool) - if True, will use the package Scour to optimize compressed svg (e.g.
           remove redundant nodes, id attributes). Saves optimized svg to 'outputfile_opt.svg'
+        optimize_options(dict) - if optimize == True, use optimize_options to pass args to 
+          vector_utils.optimize_svg. See optimize_tothe_max in vector_utils.optimize_svg for
+          default name, value pairs.
         **kwargs - depending on the compression type and the pre-selection criteria, additional 
           key word arguments may be required. See compress_by_merging, compress_by_deletion, and 
           compress_by_simplification in class Compress for the valid keyword arguments when 
@@ -391,7 +381,7 @@ def compress_by_method(filename, compression_type, curve_fidelity = 10, outputfi
     if optimize:
         outfilename, extension = outputfile.split('.') # Get filename and extension
         opti_output = '%s_opt.%s' %(outfilename, extension)
-        test_compression.optimize(inputfile, opti_output)
+        test_compression.optimize(inputfile, opti_output, optimize_options)
     test_compression.report()
 
 def test(filename, thresholds = (5, 2), epsilon = 0.5, curve_fidelity = 10, 
@@ -405,17 +395,17 @@ def test(filename, thresholds = (5, 2), epsilon = 0.5, curve_fidelity = 10,
         outputfile = ''.join((filestr, '_truncby%s.' %(criteria), extension))
         compress_by_method(filename, 'delete',  curve_fidelity, outputfile, criteria = criteria,
                            threshold = threshold)
-
+ 
     ## Compress by simplification:
     outputfile = ''.join((filestr, '_simplified.', extension))
     compress_by_method(filename, 'simplify', curve_fidelity, outputfile, pre_select = True, 
                        selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon)
-
+ 
     ## Compress by unification:
     outputfile = ''.join((filestr, '_merged.', extension))
     compress_by_method(filename, 'merge', curve_fidelity, outputfile, pre_select = True, 
                        selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon)
-
+ 
     ## Compress by convex hull:
     outputfile = ''.join((filestr, '_hull.', extension))
     compress_by_method(filename, 'merge', curve_fidelity, outputfile, pre_select = True, 
